AAl atlas for SPM 12


Notes
-----
This atlas is the result of an automated anatomical parcellation of the spatially normalized single-subject high-resolution T1 volume provided by the Montreal Neurological Institute (MNI) (D. L. Collins et al., 1998, Trans. Med. Imag. 17, 463-468, PubMed).

Using this parcellation method, three procedures to perform the automated anatomical labeling of functional studies are proposed: (1) labeling of an extremum defined by a set of coordinates, (2) percentage of voxels belonging to each of the AVOI intersected by a sphere centered by a set of coordinates, and (3) percentage of voxels belonging to each of the AVOI intersected by an activated cluster.


Content
-------
    :"regions": str. path to nifti file containing regions.
    :"labels": dict. labels dictionary with their region id as key and name as value


References
-----
For more information on this dataset's structure, see
http://www.gin.cnrs.fr/AAL-217?lang=en

Automated Anatomical Labeling of Activations in SPM Using a Macroscopic
Anatomical Parcellation of the MNI MRI Single-Subject Brain.
N. Tzourio-Mazoyer, B. Landeau, D. Papathanassiou, F. Crivello,
O. Etard, N. Delcroix, B. Mazoyer, and M. Joliot.
NeuroImage 2002. 15 :273-28

Licence: unknown.
